console.log("Starting ESP Javascript");
// Create the global namespace
ESP = {};
// Create the configuration (probably should be read from a file later)
ESP.config = {
	machines: ["Bruce", "Mack"],
	ancillaryData: {
		sources: [{
			name: "ctd",
			longName: "CTD",
			variables: [{
				name: "temperature",
				longName: "Temperature",
				units: "degrees C"
			}, {
				name: "salinity",
				longName: "Salinity",
				units: ""
			}, {
				name: "chlorophyll",
				longName: "Chloropyhll",
				units: "mg/m^3"
			}, {
				name: "depth",
				longName: "Depth",
				units: "m"
			}, {
				name: "computed_dissolved_oxygen",
				longName: "Dissolved O2",
				units: "ml/L"
			}, {
				name: "light_transmission",
				longName: "Light Transmission",
				units: "%"
			}]
		}, {
			name: "can",
			longName: "Can",
			variables: [ {
				name: "average_current",
				longName: "Average Current",
				units: "A"
			}, {
				name: "battery_voltage",
				longName: "Batter Voltage",
				units: "V"
			}, {
				name: "humidity",
				longName: "Humidity",
				units: "%"
			}, {
				name: "instantaneous_current",
				longName: "Instantaneous Current",
				units: "A"
			}, {
				name: "pressure",
				longName: "Pressure",
				units: "psi"
			}, {
				name: "temperature",
				longName: "Temperature",
				units: "degrees C"
			}, {
				name: "watts",
				longName: "Watts",
				units: "W"
			}]
		}]
	}
};
// Grab the current date and some offsets for empty initial
// data set
var now = new Date();
var nowMillis = now.getTime();
var nowMinusOneWeek = nowMillis - (1000 * 60 * 60 * 24 * 7);
var nowMinusTwoWeek = nowMillis - (1000 * 60 * 60 * 24 * 7 * 2);
var nowMinusThreeWeek = nowMillis - (1000 * 60 * 60 * 24 * 7 * 3);
var nowMinusFourWeek = nowMillis - (1000 * 60 * 60 * 24 * 7 * 4);
var nowMinusFiveWeek = nowMillis - (1000 * 60 * 60 * 24 * 7 * 5);
// Create an empty data set
var emptyData = [
	[nowMinusFiveWeek, 0.0],
	[nowMinusFourWeek, 0.0],
	[nowMinusThreeWeek, 0.0],
	[nowMinusTwoWeek, 0.0],
	[nowMinusOneWeek, 0.0],
	[nowMillis, 0.0]
];
// Create the chart used for the combined data
ESP.combinedChart = new Highcharts.StockChart({
	chart: {
		renderTo: 'combined-plot',
		type: 'spline'
	},
	rangeSelector: {
		selected: 4,
		buttons: [{
			type: 'minute',
			count: 60,
			text: '1h'
		}, {
			type: 'minute',
			count: 60 * 6,
			text: '6h'
		}, {
			type: 'minute',
			count: 60 * 12,
			text: '12h'
		}, {
			type: 'day',
			count: 1,
			text: '1d'
		}, {
			type: 'week',
			count: 1,
			text: '1w'
		}, {
			type: 'month',
			count: 1,
			text: '1m'
		}]
	},
	navigator: {
		series: {
			type: 'spline'
		}
	},
	title: {
		text: 'Ancillary Data'
	},
	series: [{
		name: ESP.config.machines[0],
		tooltip: {
			valueDecimals: 2
		},
		data: emptyData
	}, {
		name: ESP.config.machines[1],
		tooltip: {
			valueDecimals: 2
		},
		data: emptyData
	}]
});
// This method takes in an array of machine names and a source
// and variable name and updates the combined plot with the
// data from those machines, from that source, for that 
// variable
ESP.updateCombinedChart = function(machines, source, variable) {
	// First thing to do is find the configuration for the incoming source
	var ancillarySource = null;
	for (var i = 0; i < ESP.config.ancillaryData.sources.length; i++) {
		if (ESP.config.ancillaryData.sources[i].name === source) {
			ancillarySource = ESP.config.ancillaryData.sources[i];
			break;
		}
	}
	// And now for the incoming variable
	var ancillaryVariable = null;
	if (ancillarySource !== null) {
		for (var j = 0; j < ancillarySource.variables.length; j++) {
			if (ancillarySource.variables[j].name === variable) {
				ancillaryVariable = ancillarySource.variables[j];
				break;
			}
		}
	}
	// Now grab the data and plot for the machines (loop over machine array)
	if (ancillarySource !== null && ancillaryVariable !== null) {
		// Set the temperature on the chart
		ESP.combinedChart.setTitle({
			text: ancillarySource.longName + " Data"
		}, {
			text: ancillaryVariable.longName + " (" + ancillaryVariable.units + ")"
		});
		for (var k = 0; k < machines.length; k++) {
			ESP.getDataForChart(k, ancillarySource.name, ancillaryVariable.name);
		}
		// Check for depth and invert the y axis if needed
		if (ancillaryVariable.name === "depth") {
			ESP.combinedChart.yAxis[0].reversed = true;	
		} else {
			if (ESP.combinedChart.yAxis[0].reversed === true) {
				ESP.combinedChart.yAxis[0].reversed = false;	
			}
		}
	}
}
// This actually pulls the data from the server and puts it on the chart
ESP.getDataForChart = function(machineIndex, source, variable) {
	// Clear the existing data
	ESP.combinedChart.series[machineIndex].setData(emptyData, false);
	// Grab the current scope
	$.get('../../instances/' + ESP.config.machines[machineIndex] + '/data/processed/' + source + '_' + variable + '.csv', function(data) {
		// Split the lines
		var lines = data.split('\n');
		// An array of data
		var newdata = [];
		// Iterate over the lines and add categories or series
		$.each(lines, function(lineNo, line) {
			var items = line.split(',');
			// header line containes series names
			if (lineNo != 0) {
				var currentDate = "";
				$.each(items, function(itemNo, item) {
					if (itemNo == 0) {
						currentDate = item;
						if (currentDate === null || typeof currentDate === "undefined" || currentDate === "") {} else {
							var momentDate = moment(currentDate);
							currentDate = Date.parse(momentDate.format());
						}
					} else {
						if (currentDate === null || typeof currentDate === "undefined" || currentDate === "") {} else {
							newdata.push([currentDate, parseFloat(item)]);
						}
					}
				});
			}
		});
		ESP.combinedChart.series[machineIndex].setData(newdata);
	});
}
// Handle the temperature button being clicked
$('#temp-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "ctd", "temperature");
});
$('#sal-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "ctd", "salinity");
});
$('#depth-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "ctd", "depth");
});
$('#chlr-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "ctd", "chlorophyll");
});
$('#ox-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "ctd", "computed_dissolved_oxygen");
});
$('#light-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "ctd", "light_transmission");
});
$('#can-temp-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "can", "temperature");
});
$('#can-pres-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "can", "pressure");
});
$('#can-hum-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "can", "humidity");
});
$('#can-inst-curr-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "can", "instantaneous_current");
});
$('#can-avg-curr-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "can", "average_current");
});
$('#can-volt-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "can", "battery_voltage");
});
$('#can-watt-btn').bind('click', function() {
	ESP.updateCombinedChart(ESP.config.machines, "can", "watts");
});
$('#bruce-ctd-btn').bind('click', function () {
	window.open('bruce-ctd.html','_blank','resizable=yes');
});
$('#bruce-can-btn').bind('click', function () {
	window.open('bruce-can.html','_blank','resizable=yes');
});
$('#mack-ctd-btn').bind('click', function () {
	window.open('mack-ctd.html','_blank','resizable=yes');
});
$('#mack-can-btn').bind('click', function () {
	window.open('mack-can.html','_blank','resizable=yes');
});